# TorrentFile

## Version 0.6.6

### Fixed 0.6.6

    - bug that created faulty Bittorrent V2 meta files in some instances.
    - back to working as it should.

---------------------

## Version 0.6.5

### Added 0.6.5

    - Support for creating Magnet URI's
    - Added optional progress bar for torrent creation
    - Log File handler
    - CLI args page in documentation

### Fixed 0.6.5

    - verbose and logging bugs
    - multi tracker errors bug

---------------------

## Version 0.6.4

### Changed/Fixed/Added 0.6.4

    - CLI interface add subcommands
    - added interactive mode
    - Re-wrote the recheck module
    - fixed documentation and docstrings
    - linting and testing errors
    - 

---------------------

## Version 0.6.3

### Fixed 0.6.3

    - Bug that would format list of trackers incorrectly
    - CLI Bug Fixes

---------------------

## Version 0.6.2

### Fixed 0.6.2

    - Bug fixes
    - Documentation error pages

---------------------

## Version 0.6.0

## Changed v0.6.0

    - cli commands alterations

## Added v0.6.0

    - debug logging during creation process

---------------------

## Version 0.5.2

### Fixed v0.5.2

    - Major Bug that was adding `announce-list` to info dict

---------------------

## Version 0.5.0

### Added v0.5.0

    - Slew of new unit tests
    - Stricter linting features
    - Alternative method of -re-check feature

### Fixed v0.5.0

    - Bug Fixes
    - CLI help formatting errors

---------------------

## Version 0.4.8

### Changes v0.4.8

    - Algorithm for the ReCheck process has changed but produces same results.

### Improved v0.4.8

    - Additions to documentation.

---------------------

## Version 0.4.7

### Fixed v0.4.7

    - A bug that misspelled a field when creating Hybrid torrent files.

### Improved v0.4.7

    - Re-Check procedure for v2 and hybrid torrent file checking.

---------------------

## Version 0.4.6

### Improved v0.4.6

    - CLI Help and Usage Messages.
    - Expanded CLI args.

### Added v0.4.6

    - Completely new CheckerClass which replaces old Checker
    - Hooks for GUI or other 3rd party apps to hook into Checking
    - Documentation and Unit tests for new CheckerClass

---------------------

## Version 0.4.5

### Improved v0.4.5

    - Documentation and docstrings.
    - Better formating and more detailed.

### Added v0.4.5

    - More unit tests.

---------------------

## Version 0.4.3

### Fixed v0.4.3

    - Bug Fixes

---------------------

## Version 0.4.2

### Improved v0.4.2

    - The Checker feature now supports v1, v2, & hybrid .torrent file.

### Fixed v0.4.2

    - Bug in CLI for python < 3.8

---------------------

## Version 0.4.1

### Added v0.4.1

    - Added tests for hybrid class
    - logging feature
    - new cli flag to activate debug mode
    - Documentation theme.

### Fixed v0.4.1

    - Bug that allowed improper piece length values.

---------------------

## Version 0.4.0

### Fixed v0.4.0

    - Fixed bugs in creating hybrid files.

---------------------

## Version 0.3.1

### Fixes v0.3.1

    - Bug Fix that broke cli.

---------------------

## Version 0.3.0

    - This version contains many breaking changes.

### Added v0.3.0

    - Added/Improved support for hybrid meta files.
    - Many additions to testing suit including linting and coverage tests.

### Fixes v0.3.0

    - Styling fixes.
    - Bug Fixes.

---------------------

## Version 0.2.8

### Added v0.2.8

    - Prelimenary support for bittorrent hybrid meta files.
    - CI/CD integration.

### Fixes v0.2.8

    - Bug Fixes

---------------------

## Version 0.2.7

### Added v0.2.7

    - major imporvements to torrentfile-GUI.
    - minor adjustments to this package for integration.

### Fixes v0.2.7

    - Code consolidation
    - Bug Fixes

---------------------

## Version 0.2.6

### Added v0.2.6

    - Improved Documentation

### Fixes v0.2.6

    - Bug Fixes

---------------------

## Version 0.2.5

### Added v0.2.5

    - CI/CD Integration

---------------------

## Version 0.2.4

### Fixes v0.2.4

    - Bug Fixes

---------------------

## Version 0.2.3

### Fixed v0.2.3

    - Code style formating issues

---------------------

## Version 0.2.2

### Added v0.2.2

    - improved test suit

---------------------

## Version 0.2.1

### Added v0.2.1

    - Bittorrent Protocol V2 Support
    - v2 metafile options to cli
    - v2 metafile tests

---------------------

## Version 0.1.7

### Added v0.1.7

    - Docstrings Improvements
    - Documentation Improvements

### Fixed v0.1.7

    - readme file update
    - formatting

---------------------

## Version 0.1.6

### Fixed v0.1.6

    - Bug Fixes

---------------------

## Version 0.1.4

### Removed v0.1.4

    - Graphical User Interface.
    - the GUI is now packaged seperately. See README for details.

---------------------

## Version 0.1.3

## Added v0.1.3

    - Rough Bittorrent v2 protocol support
    - BugFixes

---------------------

## Version 0.1.2

## Added v0.1.2

    - Command Line Interface
    - Rough Graphical User Interface

---------------------

## Fixed v0.1.2

    - Minor Bug Fixes

---------------------

## Version 0.1.1

## Added v0.1.1

    - Test suite

## Fixed v0.1.1

    - Bug Fixes

---------------------

## Version 0.1.0

### Added v0.1.0

    - SHA256 support
    - Feeder class for seemless file switching

### Fixed v0.1.0

    - Primary function now works
    - Better docstrings
    - Bug fixes

---------------------

## Version 0.0.2

### Added v0.0.2

    - Test suite
    - bencoding support
    - hashing support

---------------------

## Version 0.0.1

    - Initial concept and planning
